function isNumber(num) {
    var re_tipo = /^\d+(\.\d+)?$/;
    return re_tipo.test(num);
}

function validar() {
    var mat   = $("input[name='matricula']").val();
    var senha = $("input[name='senha']").val();

    $("#aviso").html("");

    if (mat == "" || senha == "") {
        $("#aviso").html("Nome e senha são obrigatórios!");
        return false; 
    } else {
        var mat_int = parseInt(mat);
        if (!isNumber(mat_int)) {
            $("#aviso").html("Matrícula deve ser um número inteiro!");
            return false; 
        }
    }
    return true; 
}