#login {
    position:absolute;
    border: 1px solid #006400;
    top:20%;
    left:41%;
    padding-left: 15px;
    padding-right: 15px;
}

#aviso {
    position:relative;
    color: #f00;
    font-size: 0.8em;
}

header {
    text-align: center;
}

header h1, header h2 {
    margin: 0px;
}

input.p1 {
    position: relative;
    left: 4px;
}

input.p2 {
    position: relative;
    left: 28px;
}
